@@ -1,14 +1,17 @@
+# frozen_string_literal: true
+
 require 'cucumber/messages'
 require 'json'
 
 module Gherkin
-  DIALECT_FILE_PATH = File.expand_path("gherkin-languages.json", File.dirname(__FILE__))
+  DIALECT_FILE_PATH = File.expand_path('gherkin-languages.json', File.dirname(__FILE__))
   DIALECTS = JSON.parse File.open(DIALECT_FILE_PATH, 'r:UTF-8').read
 
   class Dialect
     def self.for(name)
       spec = DIALECTS[name]
       return nil unless spec
+
       new(spec)
     end
 
